===================================
Contributing to Ironic Python Agent
===================================

Ironic Python Agent is an agent for controlling and deploying Ironic controlled
baremetal nodes. Typically run in a ramdisk, the agent exposes a REST API for
provisioning servers.

Throughout the remainder of the document, Ironic Python Agent will be
abbreviated to IPA.

.. toctree::

    hardware_managers
    metrics
    rescue

Generated Developer Documentation
=================================

* :ref:`modindex`

.. toctree::
   :hidden:

   api/modules
